@@ -13,11 +13,14 @@ use Class::Tiny qw/foo bar/;
 
 sub BUILD {
     my $self = shift;
+    my $args = shift;
     Carp::croak("foo must be positive")
       unless defined $self->foo && $self->foo > 0;
 
     $self->bar(42) unless defined $self->bar;
     $counter++;
+
+    delete $args->{hide_me};
 }
 
 sub DEMOLISH {
